@@ -2,11 +2,13 @@ package Dist::Zilla::Plugin::Test::CreateFromMojoTemplates;
 
 use strict;
 use 5.10.1;
-our $VERSION = '0.06';
+
+our $VERSION = '0.0701'; # VERSION
+# ABSTRACT: Create Mojolicious tests from a custom template format (deprecated)
 
 use Moose;
 use File::Find::Rule;
-use namespace::sweep;
+use namespace::autoclean;
 use Path::Tiny;
 use MojoX::CustomTemplateFileParser;
 
@@ -54,13 +56,32 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
-=encoding utf-8
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
-Dist::Zilla::Plugin::Test::CreateFromMojoTemplates - Create tests from custom L<Mojolicious> templates
+Dist::Zilla::Plugin::Test::CreateFromMojoTemplates - Create Mojolicious tests from a custom template format (deprecated)
 
-=for html <p><a style="float: left;" href="https://travis-ci.org/Csson/p5-dist-zilla-plugin-test-createfrommojotemplate"><img src="https://travis-ci.org/Csson/p5-dist-zilla-plugin-test-createfrommojotemplate.svg?branch=master">&nbsp;</a>
+
+
+=begin HTML
+
+<p><img src="https://img.shields.io/badge/perl-5.10.1+-brightgreen.svg" alt="Requires Perl 5.10.1+" /> <a href="https://travis-ci.org/Csson/p5-dist-zilla-plugin-test-createfrommojotemplate"><img src="https://api.travis-ci.org/Csson/p5-dist-zilla-plugin-test-createfrommojotemplate.svg?branch=master" alt="Travis status" /></a> </p>
+
+=end HTML
+
+
+=begin markdown
+
+![Requires Perl 5.10.1+](https://img.shields.io/badge/perl-5.10.1+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-dist-zilla-plugin-test-createfrommojotemplate.svg?branch=master)](https://travis-ci.org/Csson/p5-dist-zilla-plugin-test-createfrommojotemplate) 
+
+=end markdown
+
+=head1 VERSION
+
+Version 0.0701, released 2016-01-25.
 
 =head1 SYNOPSIS
 
@@ -71,6 +92,8 @@ Dist::Zilla::Plugin::Test::CreateFromMojoTemplates - Create tests from custom L<
 
 =head1 DESCRIPTION
 
+B<Deprecated>. See L<Dist::Zilla::Plugin::Stenciller::Mojolicious> instead.
+
 Dist::Zilla::Plugin::Test::CreateFromMojoTemplates creates tests by parsing a custom file format
 containg Mojolicious templates and the expected rendering. See L<MojoX::CustomTemplateFileParser> for details.
 
@@ -78,19 +101,23 @@ It looks for files in a given C<directory> (by default C<examples/source>) that
 
 If you have many files you can also create a C<template.test> (currently hardcoded) file. Its content will be placed at the top of all created test files.
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-dist-zilla-plugin-test-createfrommojotemplate>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/Dist-Zilla-Plugin-Test-CreateFromMojoTemplates>
+
 =head1 AUTHOR
 
-Erik Carlsson E<lt>info@code301.comE<gt>
+Erik Carlsson <info@code301.com>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2014- Erik Carlsson
+This software is copyright (c) 2016 by Erik Carlsson.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=head1 SEE ALSO
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
